============
Installation
============

At the command line::

    $ easy_install py_mini_racer

Or, if you have virtualenvwrapper installed::

    $ mkvirtualenv py_mini_racer
    $ pip install py_mini_racer
